@@ -1,15 +1,17 @@
 package Spreadsheet::ParseXLSX;
-our $AUTHORITY = 'cpan:DOY';
-$Spreadsheet::ParseXLSX::VERSION = '0.27';
+
 use strict;
 use warnings;
 use 5.010;
+
+our $VERSION = '0.28'; # VERSION
+
 # ABSTRACT: parse XLSX files
 
 use Archive::Zip;
 use Graphics::ColorUtils 'rgb2hls', 'hls2rgb';
 use Scalar::Util 'openhandle';
-use Spreadsheet::ParseExcel 0.61;
+use Spreadsheet::ParseExcel;
 use XML::Twig;
 
 use Spreadsheet::ParseXLSX::Decryptor;
@@ -176,8 +178,6 @@ sub _parse_sheet {
     $sheet->{MaxCol} = -1;
     $sheet->{Selection} = [ 0, 0 ];
 
-    my %merged_cells;
-
     my @column_formats;
     my @column_widths;
     my @columns_hidden;
@@ -187,7 +187,6 @@ sub _parse_sheet {
     my $default_row_height   = 15;
     my $default_column_width = 10;
 
-    my %cells;
     my $row_idx = 0;
 
     my $sheet_xml = $self->_new_twig(
@@ -263,11 +262,6 @@ sub _parse_sheet {
                         $toprow, $leftcol,
                         $bottomrow, $rightcol,
                     ];
-                    for my $row ($toprow .. $bottomrow) {
-                        for my $col ($leftcol .. $rightcol) {
-                            $merged_cells{"$row;$col"} = 1;
-                        }
-                    }
                 }
 
                 $twig->purge;
@@ -415,7 +409,6 @@ sub _parse_sheet {
                     $cell->{_Value} = $sheet->{_Book}{FmtClass}->ValFmt(
                         $cell, $sheet->{_Book}
                     );
-                    $cells{"$row;$col"} = $cell;
                     $sheet->{Cells}[$row][$col] = $cell;
                     $col_idx++;
                 }
@@ -428,11 +421,15 @@ sub _parse_sheet {
 
     $sheet_xml->parse( $sheet_file );
 
-    for my $key (keys %merged_cells) {
-        $cells{$key}{Merged} = 1 if $cells{$key};
-    }
-
-    if ( ! $sheet->{Cells} ){
+    if ( $sheet->{Cells} ) {
+        for my $r ( 0 .. $#{ $sheet->{Cells} } ) {
+            my $row = $sheet->{Cells}[$r] or next;
+            for my $c ( 0 .. $#$row ) {
+                my $cell = $row->[$c] or next;
+                $cell->{Merged} = $self->_is_merged( $sheet, $r, $c );
+            }
+        }
+    } else {
         $sheet->{MaxRow} = $sheet->{MaxCol} = -1;
     }
 
@@ -1005,6 +1002,24 @@ sub _dimensions {
     return ($rmin, $cmin, $rmax, $cmax);
 }
 
+sub _is_merged {
+    my ( $self, $sheet, $row, $col ) = @_;
+
+    return unless $sheet->{MergedArea};
+
+    foreach my $area ( @{ $sheet->{MergedArea} } ) {
+        my ( $topRow, $leftCol, $bottomRow, $rightCol ) = @$area;
+
+        return 1
+          if $topRow <= $row
+          && $leftCol <= $col
+          && $row <= $bottomRow
+          && $col <= $rightCol;
+    }
+
+    return 0;
+}
+
 sub _cell_to_row_col {
     my $self = shift;
     my ($cell) = @_;
@@ -1055,7 +1070,7 @@ sub _color {
                 $color = "#$theme";
             }
             else {
-                return undef;
+                return;
             }
         }
 
@@ -1114,7 +1129,7 @@ Spreadsheet::ParseXLSX - parse XLSX files
 
 =head1 VERSION
 
-version 0.27
+version 0.28
 
 =head1 SYNOPSIS
 
@@ -1219,7 +1234,7 @@ XLSX spec is quite large). If you run into any of those, bug reports are quite
 welcome.
 
 Please report any bugs to GitHub Issues at
-L<https://github.com/doy/spreadsheet-parsexlsx/issues>.
+L<https://github.com/MichaelDaum/spreadsheet-parsexlsx/issues>.
 
 =head1 SEE ALSO
 
@@ -1247,7 +1262,7 @@ L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Spreadsheet-ParseXLSX>
 
 =item * Github
 
-L<https://github.com/doy/spreadsheet-parsexlsx>
+L<https://github.com/MichaelDaum/spreadsheet-parsexlsx>
 
 =item * CPAN Ratings
 
@@ -1269,9 +1284,65 @@ Parts of this code were paid for by
 
 Jesse Luehrs <doy@tozt.net>
 
+=head1 CONTRIBUTORS
+
+=for stopwords Alexey Mazurin Dave Clarke Fitz Elliott FL Meredith Howard MichaelDaum rdboisvert Ricardo Signes Robert Boisvert Steve Simms Stuart Watt zhouzhen1
+
+=over 4
+
+=item *
+
+Alexey Mazurin <mazurin.alexey@gmail.com>
+
+=item *
+
+Dave Clarke <david_clarke@verizon.net>
+
+=item *
+
+Fitz Elliott <felliott@fiskur.org>
+
+=item *
+
+FL <f20@reckon.co.uk>
+
+=item *
+
+Meredith Howard <mhoward@roomag.org>
+
+=item *
+
+MichaelDaum <daum@michaeldaumconsulting.com>
+
+=item *
+
+rdboisvert <rdbprog@gmail.com>
+
+=item *
+
+Ricardo Signes <rjbs@cpan.org>
+
+=item *
+
+Robert Boisvert <robert.boisvert@PABET-J069H12.sncrcorp.net>
+
+=item *
+
+Steve Simms <steve@deefs.net>
+
+=item *
+
+Stuart Watt <stuart@morungos.com>
+
+=item *
+
+zhouzhen1 <zhouzhen1@gmail.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Jesse Luehrs.
+This software is Copyright (c) 2024 by Jesse Luehrs.
 
 This is free software, licensed under:
 
