@@ -1,9 +1,12 @@
 package Spreadsheet::ParseXLSX::Decryptor;
-our $AUTHORITY = 'cpan:DOY';
-$Spreadsheet::ParseXLSX::Decryptor::VERSION = '0.27';
+
 use strict;
 use warnings;
 
+our $VERSION = '0.28'; # VERSION
+
+# ABSTRACT: helper class to open password protected files
+
 use Crypt::Mode::CBC;
 use Crypt::Mode::ECB;
 use Digest::SHA ();
@@ -218,11 +221,11 @@ __END__
 
 =head1 NAME
 
-Spreadsheet::ParseXLSX::Decryptor
+Spreadsheet::ParseXLSX::Decryptor - helper class to open password protected files
 
 =head1 VERSION
 
-version 0.27
+version 0.28
 
 =for Pod::Coverage   new
   open
@@ -233,7 +236,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Jesse Luehrs.
+This software is Copyright (c) 2024 by Jesse Luehrs.
 
 This is free software, licensed under:
 
