@@ -1,9 +1,12 @@
 package Spreadsheet::ParseXLSX::Decryptor::Standard;
-our $AUTHORITY = 'cpan:DOY';
-$Spreadsheet::ParseXLSX::Decryptor::Standard::VERSION = '0.27';
+
 use strict;
 use warnings;
 
+our $VERSION = '0.28'; # VERSION
+
+# ABSTRACT: standard decryption
+
 use base 'Spreadsheet::ParseXLSX::Decryptor';
 
 sub decrypt {
@@ -90,11 +93,11 @@ __END__
 
 =head1 NAME
 
-Spreadsheet::ParseXLSX::Decryptor::Standard
+Spreadsheet::ParseXLSX::Decryptor::Standard - standard decryption
 
 =head1 VERSION
 
-version 0.27
+version 0.28
 
 =for Pod::Coverage   decrypt
   decryptFile
@@ -106,7 +109,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Jesse Luehrs.
+This software is Copyright (c) 2024 by Jesse Luehrs.
 
 This is free software, licensed under:
 
